# Configuration file for the Sphinx documentation builder.

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
# type: ignore
import sys
from pathlib import Path

import toml

sys.path.insert(0, Path().resolve())


# -- Project information -----------------------------------------------------

# Read the project information from pyproject.toml
pyproject = toml.load(Path(__file__).parent.parent / "pyproject.toml")
project = pyproject["tool"]["poetry"]["name"]
author = pyproject["tool"]["poetry"]["authors"][0].split(" <")[0]
email = pyproject["tool"]["poetry"]["authors"][0].split(" <")[1].replace(">", "")
version = release = pyproject["tool"]["poetry"]["version"]
license = pyproject["tool"]["poetry"]["license"]
summary = pyproject["tool"]["poetry"]["description"]
copyright = f"Copyright 2021 {author}"


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = ["sphinx.ext.autodoc", "sphinx_copybutton"]

# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = "sphinx_rtd_theme"

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = []

copybutton_prompt_text = r">>> |\.\.\. |\$ "
copybutton_prompt_is_regexp = True
